#!/usr/local/bin/perl
#2_seq_from_file.pl
#Author: Paul Stothard
#
#This script reads a DNA sequence (in FASTA format) from a file and
#then prints some of the file contents on the screen.

use warnings;
use strict;

#The following statements prompt the user for the name of a file, and
#then store the entered name in $file_to_read.
print "Enter the name of the sequence file"
    . " (try sars.txt) and then press enter:\n";

my $file_to_read = <STDIN>;

#Remove the \n from the end.
chomp($file_to_read);

#To use a file in a Perl script, the file must first be opened and
#associated with a file handle. This is done using the "open"
#statement. The "open" statement receives two arguments: the name you
#wish to use as the handle, and the filename. The two arguments are
#separated by commas. In this case the filename is stored in the
#variable $file_to_read. If Perl cannot open the file because, for
#example, the file does not exist, the statement after the "or" is
#executed. Usually a "die" statement is placed after the "or" so that
#the program terminates and prints a message alerting the user to the
#problem. The variable "$!" is included in the message. Perl
#automatically creates this variable and stores in it the most recent
#system-error message. It will therefore contain an explanation for
#the failed "open" statement.
open( my $DNAFILE, $file_to_read )
    or die("Cannot open file '$file_to_read': $!");

#The next statement places a copy of the first line of the file in the
#variable $first_line. The diamond operator "<>" that surrounds our
#filehandle reads in the associated file until it reaches the first
#carriage return. In the sars.txt file the first line (the text before
#the first carriage return) is the title of the sequence.
my $first_line = <$DNAFILE>;

#Print the first line.
print "The first line of the file is:\n$first_line\n";

#Store the second line in another variable. Perl automatically starts
#where it left off each time the $DNAFILE handle is used.
my $second_line = <$DNAFILE>;

#Now print the second line.
print "The second line of the file is:\n$second_line\n";

#To print the entire file, you could use the following code, by
#removing the comment characters from the three lines. The portion "my
#$line = <$DNAFILE>" tries to store a line of the file in the variable
#$line. If there is a line to assign (i.e. the end of the file has not
#been reached), the statement between the curly braces "{}" is
#executed. The "while" causes this process to be repeated until the
#assignment can no longer be made (i.e. the end of the file has been
#reached).
#
#while (my $line = <$DNAFILE>) {
#   print "this line was read: $line\n";
#}

#Once you are done with a file, close the filehandle.
close($DNAFILE) or die("Cannot close file : $!");

#To run this script, use the following command:
#perl 2_seq_from_file.pl
